pub enum UpdateAction {
NoUpdate,
JwksUpdate,
CacheUpdate(Settings),
JwksAndCacheUpdate(Settings),
}Variants
NoUpdate
We checked the JWKS uri and it was the same as the last time we refreshed it so no action was taken
JwksUpdate
We checked the JWKS uri and it was different so we updated our local cache
CacheUpdate(Settings)
The JWKS Uri responded with a different cache-control header
JwksAndCacheUpdate(Settings)